Problem Index

# Honey Crumpets

A logic problem by Brandon Bennett

Your problem is to use first-order logic to represent the following example of reasoning, and use the Prover9 theorem prover to prove that the reasoning is valid.

You should use the following template file to create your Prover9 encoding of the problem:
`honey_crumpets.p9`

Marks: There are two marks for each sentence, making a total of 36 marks.

Outline: The domain is crumpets. I have four crumpets on a plate. Two are honey crumpets and the other two just butter. I can eat two crumpets but must leave two for my freind. Of course, I want to have at least one of the Honey crumpets. But unfortunately, the warm honey has run into the crumpets, and I can't tell, or remember, which are the honey ones. :( However, I do remember that the two honey crumpets were next to each other.

## Problem Statement

A1: All crumpets have butter or honey on them.

A2: No crumpet has both honey and butter.

A3: There are two honey crumpets.

A4: There are not three different crumpets with honey on them.

A5: There are two buttered crumpets.

A6: There are not three different crumpets with butter on them.

A7: Any two different crumpets are either next to each other or diagonally opposite.

A8: No two crumpets are next to each other and diagonally opposite.

A9: No crumpet is next to itself.

A10: No crumpet is diagonally opposite itself

A11: If any crumpet A is next to any crumpet B then B is also next to A.

A12: If any crumpet A is diagonally opposite any crumpet B then B is also diagonally opposite A.

A13: Every crumpet is diagonally opposite another crumpet.

A14: Every crumpet is next to two different crumpets.

A15: There are two honey crumpets which are next to each other.

A16: I ate two diagonally opposite crumpets.

A17: If a crumpet A is diagonally opposite another crumpet B, and B is diagonally opposite another crumpet C, then A is C.

Goal: I ate a honey crumpet.

### Non-Logical Vocabulary

Predicates: `Honey`, `Butter`, `NextTo`, `Diagonal`, `Ate`

#### Notes:

- The NextTo and Diagonal relations are both anti-relfexive and symmetric.